==> react-bootstrap-select-0.12.3.tgz: package/README.md <==
## react-bootstrap-select

[![NPM version][npm-image]][npm-url]
[![Build status][ci-image]][ci-url]
[![Dependency Status][daviddm-image]][daviddm-url]

A custom select / multiselect for Bootstrap using button dropdown, designed to behave like regular Bootstrap selects.
Tested with React 0.12 and Bootstrap 3.

<img src="http://cdn.tjw.io/videos/react-bootstrap-select-demo.gif"
height="360px" />

### 1. Install
```sh
$ npm install react-bootstrap-select --save
```

### 2. Usage

BootstrapSelect = require('react-bootstrap-select');

Create your `<bs.Select>` with the `.selectpicker` class.
```html
<BootstrapSelect>
  <option>Mustard</option>
  <option>Ketchup</option>
  <option>Barbecue</option>
</BootstrapSelect>
```

### 3. Demo and Documentation

See a Bootstrap 3 example [here](http://tjwebb.github.io/bootstrap-select).

## License
MIT

Checkout the [documentation](http://tjwebb.github.io/bootstrap-select) for further information.

[npm-image]: https://img.shields.io/npm/v/react-bootstrap-select.svg?style=flat-square
[npm-url]: https://npmjs.org/package/react-bootstrap-select
[sails-logo]: http://cdn.tjw.io/images/sails-logo.png
[sails-url]: https://sailsjs.org
[ci-image]: https://img.shields.io/circleci/project/cnect/react-bootstrap-select.svg?style=flat-square
[ci-url]: https://circleci.com/gh/cnect/react-bootstrap-select
[daviddm-image]: http://img.shields.io/david/cnect/react-bootstrap-select.svg?style=flat-square
[daviddm-url]: https://david-dm.org/cnect/react-bootstrap-select

==> react-bootstrap-select-0.12.5.tgz: package/README.md <==
## react-bootstrap-select

[![NPM version][npm-image]][npm-url]
[![Build status][ci-image]][ci-url]
[![Dependency Status][daviddm-image]][daviddm-url]

A custom select / multiselect for Bootstrap using button dropdown, designed to behave like regular Bootstrap selects.
Tested with React 0.12 and Bootstrap 3.

<img src="http://cdn.tjw.io/videos/react-bootstrap-select-demo.gif"
height="360px" />

### 1. Install
```sh
$ npm install react-bootstrap-select --save
```

### 2. Usage
```js
React = require('react');
React.Bootstrap = require('react-bootstrap');
React.Bootstrap.Select = require('react-bootstrap-select');
```
```html
<React.Bootstrap.Select>
  <option>Mustard</option>
  <option>Ketchup</option>
  <option>Barbecue</option>
</React.Bootstrap.Select>
```

### 3. Demo and Documentation

See a Bootstrap 3 example [here](http://tjwebb.github.io/bootstrap-select).

## License
MIT

Checkout the [documentation](http://tjwebb.github.io/bootstrap-select) for further information.

[npm-image]: https://img.shields.io/npm/v/react-bootstrap-select.svg?style=flat-square
[npm-url]: https://npmjs.org/package/react-bootstrap-select
[sails-logo]: http://cdn.tjw.io/images/sails-logo.png
[sails-url]: https://sailsjs.org
[ci-image]: https://img.shields.io/circleci/project/cnect/react-bootstrap-select.svg?style=flat-square
[ci-url]: https://circleci.com/gh/cnect/react-bootstrap-select
[daviddm-image]: http://img.shields.io/david/cnect/react-bootstrap-select.svg?style=flat-square
[daviddm-url]: https://david-dm.org/cnect/react-bootstrap-select
